import{M as r}from"./Modal.b6d9a624.js";import{d as a,E as _,r as c,a as f,b as d,c as l,e as n,eq as i,bw as m,er as u,t as p}from"./registerWidgets.d68712f0.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="e00ae36b-1656-43f0-b6f4-ff38f7352053",e._sentryDebugIdIdentifier="sentry-dbid-e00ae36b-1656-43f0-b6f4-ff38f7352053")}catch{}})();const b=["src"],y=a({__name:"Home",setup(e){const o=_({onboardingForm:""}),t=c(null);return(g,w)=>{const s=f("router-view");return d(),l(m,null,[n(s,{class:"router"}),n(r,{ref_key:"modal",ref:t},{content:i(()=>[u("iframe",{class:"form",src:o.onboardingForm},null,8,b)]),_:1},512)],64)}}});const x=p(y,[["__scopeId","data-v-7e290e34"]]);export{x as default};
//# sourceMappingURL=Home.795fb9eb.js.map
