import{t,b as s,c as a}from"./registerWidgets.d68712f0.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="39f5ad17-8695-49c9-aa46-6431ee682bb7",e._sentryDebugIdIdentifier="sentry-dbid-39f5ad17-8695-49c9-aa46-6431ee682bb7")}catch{}})();const o={},r={class:"organization-settings"};function i(e,n){return s(),a("div",r,"Organization settings")}const f=t(o,[["render",i]]);export{f as default};
//# sourceMappingURL=OrganizationSettings.589832f3.js.map
