import{d as f,ey as b,ex as C,F as _,b as g,u as w,bu as I}from"./registerWidgets.d68712f0.js";import{b as h}from"./index.8465c60e.js";import"./gateway.f055664d.js";import{C as s}from"./connector.5e64778f.js";import{a as k}from"./asyncComputed.f9ea598c.js";import{f as x,q as D}from"./icons.24d45fbf.js";import{C as E}from"./CrudView.dbd62bcc.js";import"./passwordlessManager.36ac2e38.js";import"./pubsub.5d7eaeae.js";import"./activeRecord.b8754928.js";import"./DropdownMenu.96853481.js";import"./Modal.b6d9a624.js";import"./LoadingIndicator.bd782213.js";import"./lottie.2b6a117e.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[n]="ca930646-50d6-4531-8065-ed7e09e50b53",o._sentryDebugIdIdentifier="sentry-dbid-ca930646-50d6-4531-8065-ed7e09e50b53")}catch{}})();const G=f({__name:"Connectors",setup(o){const n=b(),r=C(),c=n.params.projectId;async function i(e){const t=await s.create(c,e.name,e.type);r.push({name:"connectorEditor",params:{connectorId:t.id}})}const l=[{key:"name",label:"Connector name",type:"text"},{key:"type",label:"Connector type",type:Object.entries(h.schema).map(([e,t])=>({value:e,label:t.label}))}],{loading:d,result:p,refetch:m}=k(()=>s.list(c)),u=_(()=>{var e,t;return{columns:[{name:"Name"},{name:"Type"},{name:"actions"}],rows:(t=(e=p.value)==null?void 0:e.map(a=>({key:a.id,cells:[{text:a.name,classes:["centered"]},{text:a.type},{text:"Actions",classes:["centered"],actions:[{icon:x,label:"Edit",onClick({key:y}){r.push({name:"connectorEditor",params:{connectorId:y}})}},{icon:D,label:"Delete",dangerous:!0,async onClick(){await a.delete(),m()}}]}]})))!=null?t:[]}});return(e,t)=>(g(),w(E,{"entity-name":"connector",loading:I(d),title:"Connectors",description:"Each connector is a version of your app. You can create a new connector by deploying your app from the local editor.","empty-title":"No connectors here yet",table:u.value,fields:l,"create-button-text":"Create connector",onCreate:i},null,8,["loading","table"]))}});export{G as default};
//# sourceMappingURL=Connectors.9ca75d64.js.map
