import{d as y,es as _,E as v,b as l,c,er as i,bu as b,et as d,c2 as p,eu as m,ev as S,ew as g,t as k}from"./registerWidgets.d68712f0.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="76efc092-98d6-40dc-82dd-82310ad6d00d",e._sentryDebugIdIdentifier="sentry-dbid-76efc092-98d6-40dc-82dd-82310ad6d00d")}catch{}})();const w=y({__name:"Modal",props:{containerStyle:{},headerStyle:{},contentStyle:{}},emits:["open","close"],setup(e,{expose:t,emit:n}){const f=_(),u=()=>{o.isOpened=!0,n("open")},a=()=>{o.isOpened=!1,n("close")};t({open:u,close:a});const o=v({isOpened:!1});return(s,r)=>(l(),c("div",{class:g(["background",o.isOpened&&"visible"]),onClick:a},[i("div",{class:"container",style:d(s.containerStyle),onClick:r[0]||(r[0]=S(()=>{},["stop"]))},[b(f).header?(l(),c("div",{key:0,class:"header",style:d(s.headerStyle)},[p(s.$slots,"header",{},void 0,!0)],4)):m("",!0),i("div",{class:"content",style:d(s.contentStyle)},[p(s.$slots,"content",{},void 0,!0)],4)],4)],2))}});const I=k(w,[["__scopeId","data-v-24f739ca"]]);export{I as M};
//# sourceMappingURL=Modal.b6d9a624.js.map
