import{L as t}from"./lottie.2b6a117e.js";import{d as a,r,o as s,b as d,c as i,er as c,c2 as _,t as l}from"./registerWidgets.d68712f0.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[e]="9449eba0-9867-4145-8b61-367281e2d1f1",n._sentryDebugIdIdentifier="sentry-dbid-9449eba0-9867-4145-8b61-367281e2d1f1")}catch{}})();const u={class:"container"},f=a({__name:"LoadingIndicator",setup(n){const e=r(null);return s(()=>{!e.value||t.loadAnimation({container:e.value,renderer:"svg",loop:!0,autoplay:!0,path:"/circularLoading.json"})}),(o,p)=>(d(),i("div",u,[c("div",{ref_key:"animation",ref:e,class:"animation"},null,512),_(o.$slots,"default",{},void 0,!0)]))}});const g=l(f,[["__scopeId","data-v-c30401d8"]]);export{g as L};
//# sourceMappingURL=LoadingIndicator.bd782213.js.map
