import{d as u,ey as b,F as l,a as g,b as _,c as v,e as r,er as p,bw as f,t as y}from"./registerWidgets.d68712f0.js";import{a as h}from"./asyncComputed.f9ea598c.js";import{P as j}from"./project.b6900e18.js";import"./gateway.f055664d.js";import{O as z}from"./organization.f45635ab.js";import"./index.8465c60e.js";import{N as I}from"./Navbar.ab57810c.js";import{S as w}from"./Sidebar.82eec760.js";import{F as P,G as k,H as x,I as B,J as C,K as D,L as $,C as E,D as M,E as N}from"./icons.24d45fbf.js";import"./activeRecord.b8754928.js";import"./pubsub.5d7eaeae.js";import"./passwordlessManager.36ac2e38.js";import"./logo.084e5d7c.js";import"./Tooltip.a8cfc3b1.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[s]="a4ece088-2796-4715-96e0-2c80fb063e17",o._sentryDebugIdIdentifier="sentry-dbid-a4ece088-2796-4715-96e0-2c80fb063e17")}catch{}})();const S={class:"project"},F={class:"content-wrapper"},L=u({__name:"Project",setup(o){const i=b().params.projectId,{result:e}=h(()=>j.get(i).then(async a=>{const t=await z.get(a.organizationId);return{project:a,organization:t}})),m=l(()=>{var a,t,n,c;return((a=e.value)==null?void 0:a.organization)&&e.value.project?[{label:"My organizations",path:"/organizations"},{label:(n=(t=e.value)==null?void 0:t.organization)==null?void 0:n.name,path:`/organizations/${(c=e.value)==null?void 0:c.organization.id}`},{label:e.value.project.name,path:`/projects/${e.value.project.id}`}]:void 0}),d=l(()=>{var a;return(a=e.value)!=null&&a.project?[{name:"Project",items:[{name:"Builds",path:"builds",icon:P},{name:"Connectors",path:"connectors",icon:k},{name:"Tables",path:"tables",icon:x},{name:"API Keys",path:"api-keys",icon:B},{name:"Env Vars",path:"env-vars",icon:C},{name:"Logs",icon:D,path:"logs",beta:!0},{name:"Settings",icon:$,path:"settings"}]},{name:"Organization",items:[{name:"Projects",icon:E,path:`/organizations/${e.value.project.organizationId}/projects`},{name:"Members",icon:M,path:`/organizations/${e.value.project.organizationId}/members`},{name:"Billing",icon:N,path:`/organizations/${e.value.project.organizationId}/billing`,unavailable:!0}]}]:[]});return(a,t)=>{const n=g("router-view");return _(),v(f,null,[r(I,{class:"nav",breadcrumb:m.value},null,8,["breadcrumb"]),p("div",S,[r(w,{class:"sidebar",sections:d.value},null,8,["sections"]),p("div",F,[r(n)])])],64)}}});const Y=y(L,[["__scopeId","data-v-b94e9a36"]]);export{Y as default};
//# sourceMappingURL=Project.ee319e10.js.map
