import{u as s}from"./icons.24d45fbf.js";import{d as r,a as c,b as d,c as i,e as _,bu as l,bh as u,t as b}from"./registerWidgets.d68712f0.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="103b52b8-4e5e-4930-add2-b531a0526c39",e._sentryDebugIdIdentifier="sentry-dbid-103b52b8-4e5e-4930-add2-b531a0526c39")}catch{}})();const p=r({__name:"BackButton",emits:["exitFullscreenPreview"],setup(e,{emit:t}){return(o,n)=>{const a=c("icon");return d(),i("button",{class:"back-btn",onClick:n[0]||(n[0]=f=>t("exitFullscreenPreview"))},[_(a,{class:"icon",path:l(s),width:"20",height:"20",fill:"#5A677A"},null,8,["path"]),u(" Editor ")])}}});const w=b(p,[["__scopeId","data-v-eaeb3a6e"]]);export{w as B};
//# sourceMappingURL=BackButton.2f4b66ab.js.map
