import{S as c}from"./Sidebar.82eec760.js";import{N as d}from"./Navbar.ab57810c.js";import{C as m,D as p,E as l}from"./icons.24d45fbf.js";import{d as u,ey as _,F as b,a as g,b as f,c as v,e as t,er as y,bw as z,t as w}from"./registerWidgets.d68712f0.js";import{a as h}from"./asyncComputed.f9ea598c.js";import"./gateway.f055664d.js";import{O as I}from"./organization.f45635ab.js";import"./index.8465c60e.js";import"./Tooltip.a8cfc3b1.js";import"./logo.084e5d7c.js";import"./passwordlessManager.36ac2e38.js";import"./pubsub.5d7eaeae.js";import"./activeRecord.b8754928.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="03619fca-3de2-4dca-90c5-148d6662e4ca",e._sentryDebugIdIdentifier="sentry-dbid-03619fca-3de2-4dca-90c5-148d6662e4ca")}catch{}})();const O={class:"organization"},D=u({__name:"Organization",setup(e){const n=_().params.organizationId,{result:o}=h(()=>I.get(n)),r=b(()=>o.value?[{label:"My organizations",path:"/organizations"},{label:o.value.name,path:`/organizations/${o.value.id}`}]:void 0),i=[{name:"Organization",items:[{name:"Projects",icon:m,path:"projects"},{name:"Members",icon:p,path:"members"},{name:"Billing",icon:l,path:"billing",unavailable:!0}]}];return(k,x)=>{const s=g("router-view");return f(),v(z,null,[t(d,{breadcrumb:r.value},null,8,["breadcrumb"]),y("div",O,[t(c,{class:"sidebar",sections:i}),t(s)])],64)}}});const A=w(D,[["__scopeId","data-v-51ce7239"]]);export{A as default};
//# sourceMappingURL=Organization.078dc5bb.js.map
