import{d as b,ex as k,F as y,b as h,u as g,bu as _}from"./registerWidgets.d68712f0.js";import{e as H,f as w,g as C}from"./icons.24d45fbf.js";import{a as x}from"./asyncComputed.f9ea598c.js";import{H as d}from"./hooks.76ebbffe.js";import{R as I}from"./RuntimeList.0775f6b1.js";import"./activeRecord.b8754928.js";import"./pubsub.5d7eaeae.js";import"./DropdownMenu.96853481.js";import"./CircularLoading.3dc537f5.js";import"./lottie.2b6a117e.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[n]="09aa9a05-bebe-4fb3-aefb-79875bde3b5a",a._sentryDebugIdIdentifier="sentry-dbid-09aa9a05-bebe-4fb3-aefb-79875bde3b5a")}catch{}})();const $=b({__name:"Hooks",setup(a){const n=k(),{loading:r,result:s,refetch:l}=x(()=>d.list()),c=({key:e})=>n.push({path:`/_editor/hook/${encodeURIComponent(e)}`}),u=async({key:e})=>{var o,t;await((t=(o=s.value)==null?void 0:o.find(i=>i.path===e))==null?void 0:t.duplicate()),l()},p=async()=>{const e=await d.create();c({key:e.path})},m=async({key:e})=>{var o,t;confirm("Are you sure you want to delete this hook?")&&(await((t=(o=s.value)==null?void 0:o.find(i=>i.path===e))==null?void 0:t.delete()),l())},f=y(()=>{var e,o;return{columns:[{name:"Hook Name"},{name:"Path"},{name:"Hook Actions"}],rows:(o=(e=s.value)==null?void 0:e.map(t=>({key:t.path,cells:[{text:t.title,classes:["title","centered"],link:`/_editor/hook/${encodeURIComponent(t.path)}`},{text:t.path},{text:"",classes:["centered"],actions:[{icon:H,label:"Delete",onClick:m,dangerous:!0},{icon:w,label:"Edit Hook",onClick:c},{icon:C,label:"Duplicate",onClick:u}]}]})))!=null?o:[]}});return(e,o)=>(h(),g(I,{loading:_(r),title:"Python Hooks",description:"Trigger your Python scripts with a request.","create-button-text":"Create Hook","empty-title":"No hooks here yet",table:f.value,onCreate:p},null,8,["loading","table"]))}});export{$ as default};
//# sourceMappingURL=Hooks.dd34c08d.js.map
