import{d as p,ey as u,F as m,b as f,u as b,eq as _,bu as y,eB as g,eC as w,er as d,bh as i,t as h}from"./registerWidgets.d68712f0.js";import{a as I}from"./asyncComputed.f9ea598c.js";import"./gateway.f055664d.js";import{B as x}from"./build.e05db995.js";import"./index.8465c60e.js";import{C as v}from"./CrudView.dbd62bcc.js";import{K as B,M as C}from"./icons.24d45fbf.js";import{r as D}from"./console.67ecd3e3.js";import{f as k}from"./index.b048d0fb.js";import"./passwordlessManager.36ac2e38.js";import"./pubsub.5d7eaeae.js";import"./activeRecord.b8754928.js";import"./DropdownMenu.96853481.js";import"./Modal.b6d9a624.js";import"./LoadingIndicator.bd782213.js";import"./lottie.2b6a117e.js";import"./index.ba76e763.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="b9af3d7e-2688-4dec-9f88-24bfcb8bd08a",e._sentryDebugIdIdentifier="sentry-dbid-b9af3d7e-2688-4dec-9f88-24bfcb8bd08a")}catch{}})();const S=e=>(g("data-v-e61ab2b9"),e=e(),w(),e),V=S(()=>d("div",{class:"instructions"},[i(" Get started with the local editor in seconds: "),d("pre",null,`    $ pip install abstra --upgrade
    $ abstra serve ./your-project-directory
    `),i(" And you're done! Explore the local editor and start building apps. ")],-1)),j=p({__name:"Builds",setup(e){const a=u().params.projectId,{loading:n,result:c}=I(()=>x.list(a)),l=m(()=>{var s,r;return{columns:[{name:"Id"},{name:"Date"},{name:"Status"},{name:"Actions"}],rows:(r=(s=c.value)==null?void 0:s.map(t=>({key:t.id,cells:[{text:t.id.slice(0,8),classes:["centered"]},{text:k(t.createdAt,Date.now(),{addSuffix:!0}),classes:[]},{text:t.status+(t.log?": "+t.log:""),classes:[]},{text:"",classes:["centered"],actions:[{icon:B,label:"View logs",onClick:()=>D.push({name:"logs",params:{projectId:a},query:{buildId:t.id}})},{icon:C,label:"Download files",onClick:()=>t.download()}]}]})))!=null?r:[]}});return(s,r)=>(f(),b(v,{"entity-name":"build",loading:y(n),title:"Builds",description:"Each build is a version of your app. You can create a new build by deploying your app from the local editor.","empty-title":"No builds here yet",table:l.value},{"empty-description":_(()=>[V]),_:1},8,["loading","table"]))}});const P=h(j,[["__scopeId","data-v-e61ab2b9"]]);export{P as default};
//# sourceMappingURL=Builds.1567d329.js.map
