import{P as r}from"./Passwordless.4c10fad4.js";import{d as a,ex as c,b as i,c as d,e as s,eq as _,t as f}from"./registerWidgets.d68712f0.js";import{M as m}from"./member.b0b8cd98.js";import{W as p}from"./WidgetsFrame.0ac81da1.js";import"./CircularLoading.3dc537f5.js";import"./lottie.2b6a117e.js";import"./icons.24d45fbf.js";import"./passwordlessManager.36ac2e38.js";import"./pubsub.5d7eaeae.js";import"./gateway.f055664d.js";import"./activeRecord.b8754928.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="06c917db-ceca-4ac9-8417-206cc2fb10fc",e._sentryDebugIdIdentifier="sentry-dbid-06c917db-ceca-4ac9-8417-206cc2fb10fc")}catch{}})();const l={class:"login"},u=a({__name:"Login",setup(e){const o=c();async function t(n){await m.login(),o.push({name:"home"})}return(n,b)=>(i(),d("div",l,[s(p,{theme:"white","main-color":"#d14056","font-family":"sans-serif",runtime:"dash"},{default:_(()=>[s(r,{class:"passwordless",onDone:t})]),_:1})]))}});const B=f(u,[["__scopeId","data-v-0e3dc783"]]);export{B as default};
//# sourceMappingURL=Login.d85e9c73.js.map
