import{d as u,ey as b,F as f,b as y,u as g,bu as _}from"./registerWidgets.d68712f0.js";import{a as w}from"./asyncComputed.f9ea598c.js";import"./gateway.f055664d.js";import{M as s}from"./member.b0b8cd98.js";import"./index.8465c60e.js";import{C as I}from"./CrudView.dbd62bcc.js";import"./passwordlessManager.36ac2e38.js";import"./pubsub.5d7eaeae.js";import"./activeRecord.b8754928.js";import"./DropdownMenu.96853481.js";import"./Modal.b6d9a624.js";import"./LoadingIndicator.bd782213.js";import"./lottie.2b6a117e.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="581e1b63-6bf6-488f-a823-a25c45b7024c",e._sentryDebugIdIdentifier="sentry-dbid-581e1b63-6bf6-488f-a823-a25c45b7024c")}catch{}})();const L=u({__name:"Members",setup(e){const o=b().params.organizationId,i=[{key:"email",label:"Email"}],m=async t=>{await s.create(o,t.email),d()},{loading:l,result:c,refetch:d}=w(()=>s.list(o)),p=f(()=>{var t,r;return{columns:[{name:"Email"},{name:"Role"}],rows:(r=(t=c.value)==null?void 0:t.map(n=>({key:n.email,cells:[{text:n.email,classes:["title","centered"]},{text:n.role,classes:["centered"]}]})))!=null?r:[]}});return(t,r)=>(y(),g(I,{"entity-name":"members",loading:_(l),title:"Organization members",description:"List all organization members.","empty-title":"No members yet",table:p.value,"create-button-text":"Add members",fields:i,onCreate:m},null,8,["loading","table"]))}});export{L as default};
//# sourceMappingURL=Members.5faa739f.js.map
