import{t as o,a as r,b as i,u as c,f as d,g as p,_,h as u,k as l,T as f,P as h,C as b,M as g,s as y,i as m,j as s,l as v,m as w,n as k}from"./registerWidgets.d68712f0.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="b18c24ca-1e93-42fa-b4c8-6da4334fb7cd",e._sentryDebugIdIdentifier="sentry-dbid-b18c24ca-1e93-42fa-b4c8-6da4334fb7cd")}catch{}})();const I={};function A(e,t){const n=r("router-view");return i(),c(n,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const x=o(I,[["render",A]]),a=d({history:p("/"),routes:[{path:"/:path(.*)*",name:"player",component:()=>_(()=>import("./Player.4772a3c1.js"),["assets/Player.4772a3c1.js","assets/index.ba76e763.js","assets/registerWidgets.d68712f0.js","assets/registerWidgets.0290dcd2.css","assets/uuid.5562c163.js","assets/broker.b05c3be4.js","assets/passwordlessManager.36ac2e38.js","assets/pubsub.5d7eaeae.js","assets/Passwordless.4c10fad4.js","assets/CircularLoading.3dc537f5.js","assets/lottie.2b6a117e.js","assets/CircularLoading.f81b57b4.css","assets/icons.24d45fbf.js","assets/Passwordless.86ac0c56.css","assets/executeJs.d912d6e8.js","assets/PlayerNavbar.b92fdfe8.js","assets/PlayerNavbar.76a7eb2f.css","assets/Steps.c8a993da.js","assets/Steps.998aa76d.css","assets/Modal.b6d9a624.js","assets/Modal.5aaf8eba.css","assets/executeJs.887e9a58.css","assets/WidgetsFrame.0ac81da1.js","assets/WidgetsFrame.0816a5f5.css","assets/ActionButton.vue_vue_type_script_setup_true_lang.2d629984.js","assets/broker.95c7aa9a.css","assets/DashPlayer.49110b1f.js","assets/DashPlayer.4868beea.css","assets/asyncComputed.f9ea598c.js","assets/Player.77337a17.css"])}],scrollBehavior(e){if(e.hash)return{el:e.hash}}});class D{static init(){setInterval(()=>fetch("/_healthcheck"),20*1e3)}}const W=()=>{const e=u({render:()=>l(x)});f.init(),D.init(),e.use(a),e.use(h),e.mount("#app"),e.component("VSelect",b),e.component("Markdown",g),e.component("Message",y),m(e,a),s(e,v),s(e,w),s(e,k)};W();
//# sourceMappingURL=player.56b071f1.js.map
